declare type Overwrite<T, U> = Pick<T, Exclude<keyof T, keyof U>> & U;
declare type ColorProfile = [string, number, number, number, number];
declare type ColorProfiles = {
    [key: string]: ColorProfile;
};
declare type DefaultColorProfile = "hsldefault" | "default" | "dark" | "light" | "pastel" | "wide" | "superwide" | "saturated" | "greyscale";
declare type AllInputOptions = {
    colorProfile: DefaultColorProfile | ColorProfile;
    hueCenter: number;
    hueScale: number;
    generator: "halton" | "primeWalk";
    primeWalkHueDistance: number;
};
declare type InputOptions = Partial<AllInputOptions>;
declare type OutputOptions = Overwrite<AllInputOptions, {
    colorProfile: DefaultColorProfile | "user";
}>;
declare type Input = string | number;
declare type IDeterminatic = {
    getColor(input: Input): string | undefined;
};

declare const Determinatic: (inputOptions?: InputOptions) => {
    getColor: (this: IDeterminatic, key: Input) => string | undefined;
};

export { AllInputOptions, ColorProfile, ColorProfiles, DefaultColorProfile, Determinatic, IDeterminatic, Input, InputOptions, OutputOptions };
